View source: R/make_reverse_score.R
| make_reverse_score | R Documentation |
Create Reverse Scores as New Columns
make_reverse_score(data, vars, min_val, max_val, suffix = "_rev")
data |
A data frame. |
vars |
A character vector of column names to reverse. |
min_val |
The minimum possible score of the scale. |
max_val |
The maximum possible score of the scale. |
suffix |
A character string to append to the new column names. Defaults to "_rev". |
A data frame containing the original data plus the new reversed columns.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.